@@ -2,19 +2,14 @@ import argparse
 import sys
 import gzip
 import os
-import shutil
 import logging
 import pandas as pd
-from multiprocessing import Pool
-from functools import partial, reduce
 from contextlib import contextmanager, redirect_stderr, redirect_stdout
 from os import devnull
-import tqdm
 from x_filter import __version__
 import time
 from itertools import chain
 from pathlib import Path
-from operator import or_
 import datatable as dt
 
 log = logging.getLogger("my_logger")
@@ -326,10 +321,11 @@ def create_output_files(prefix, input):
         prefix = Path(input).resolve().stem.split(".")[0]
     # create output files
     out_files = {
-        "multimap": f"{prefix}_multimap.tsv.gz",
+        "multimap": f"{prefix}_no-multimap.tsv.gz",
         "coverage": f"{prefix}_cov-stats.tsv.gz",
         "kegg_coverage": f"{prefix}_kegg-cov-stats.tsv.gz",
         "group_abundances": f"{prefix}_group-abundances.tsv.gz",
+        "group_abundances_agg": f"{prefix}_group-abundances-agg.tsv.gz",
     }
     return out_files
 
